/**
 * Mock 是一种用于模拟真实数据或服务的技术，通常在软件开发和测试中使用。其主要目的是在没有真实后端服务的情况下，提供假数据或假接口，以便开发者可以独立进行前端开发和测试。
 *
 * Mock 的主要用途：
 *
 * 前端开发：在后端接口尚未完成时，前端开发者可以使用 Mock 数据进行开发，确保用户界面的功能和交互正常。
 *
 * 测试：Mock 可以用于单元测试和集成测试，模拟各种场景和边界条件，以验证应用程序的行为。
 *
 * 性能测试：通过模拟高并发请求，开发者可以测试系统在不同负载下的表现。
 */
export default [
    {
        url: '/config',
        method: 'get',
        statusCode: 200,
        response: ({url, query, body, headers}) => {
            //dev模式使用mock加载配置测试
            return {
                //自定配置,可使用get_conf获取
                conf: {load: "web", login: false, user: 'admin'},
                //是否开启进度条
                load_bar: true,
                //是否开启加载图标
                load_ico: true,
                //默认语言
                locale: "cn",
                //回退语言
                fallback: "cn",
                //语言列表
                lang: {
                    cn: {title: "项目示例标题", text: "远程配置可以追加和替换"},
                    en: {title: "Project sample title"}
                },
                //跳由不存在时跳转,false不跳转
                error: '/',
                //动态路由
                routing: {
                    //是否开启动态路由
                    status: true,
                    //动态路由默认首页文件
                    index: "index",
                    //动态路由分组,目录:首页
                },
                //路由列表,只有path不一样,不要带view目录和vue格式,别的参数和官方一样
                route: [{path: "home", alias: "/", component: "qrcode"}]
            };
        },
    },
    {
        url: '/mock/get',
        method: 'get',
        statusCode: 200,
        response: ({url, query, body, headers}) => {
            return {
                code: 200,
                data: {
                    msg: 'mock/get',
                    url,
                    query,
                    body,
                    headers
                },
            };
        },
    },
    {
        url: '/mock/post',
        method: 'post',
        statusCode: 200,
        response: ({url, query, body, headers}) => {
            return {
                code: 200,
                data: {
                    msg: 'mock/post',
                    url,
                    query,
                    body,
                    headers
                },
            };
        },
    },
];
